////////////////////////////////////////////////////////////////////////////////
// Filename: fontclass.h
////////////////////////////////////////////////////////////////////////////////
#ifndef _FONTCLASS_H_
#define _FONTCLASS_H_


//////////////
// INCLUDES //
//////////////
#include <d3d10.h>
#include <d3dx10.h>
#include <fstream>
using namespace std;


////////////////////////////////////////////////////////////////////////////////
// Class name: FontClass
////////////////////////////////////////////////////////////////////////////////
class FontClass
{
private:
	struct FontType
	{
		float left, right;
		int size;
	};

	struct VertexType
	{
		D3DXVECTOR3 position;
	    D3DXVECTOR2 texture;
	};

public:
	FontClass();
	FontClass(const FontClass&);
	~FontClass();

	bool Initialize(ID3D10Device*, HWND, D3DXMATRIX);
	void Shutdown();

	void BuildVertexArray(void*, char*, float, float);

	void SetMatrices(D3DXMATRIX, D3DXMATRIX);
	void SetShaderPixelColor(D3DXVECTOR4);

	void RenderShader(ID3D10Device*, int);

private:
	bool LoadShader(ID3D10Device*, HWND);
	void ShutdownShader();

	bool LoadTexture(ID3D10Device*);
	void ShutdownTexture();

	bool LoadFontData();
	void ShutdownFontData();

private:
	D3DXMATRIX m_baseViewMatrix;

	ID3D10Effect* m_effect;
	ID3D10EffectTechnique* m_technique;
	ID3D10InputLayout* m_layout;

	ID3D10EffectMatrixVariable* m_worldMatrixPtr;
	ID3D10EffectMatrixVariable* m_viewMatrixPtr;
	ID3D10EffectMatrixVariable* m_projectionMatrixPtr;

	ID3D10EffectShaderResourceVariable* m_texturePtr;
	ID3D10EffectVectorVariable* m_pixColorPtr;
	ID3D10ShaderResourceView* m_texture;

	FontType* m_Font;
};

#endif